<?php

namespace Seocify;

defined('ABSPATH') || exit;


class Converter {

	const OK_FA4_TO_5_FLAG = 'seocify__fa_5_updated';

	private $force_update = false;
	private $backup_key = '_orig';


	/**
	 * Converter constructor.
	 *
	 * @param bool $force
	 */
	public function __construct($force = false) {

		$this->force_update = $force;

		if($force === true) {

			$this->backup_key = '_force';
		}
	}


	/**
	 *
	 * @since 1.0.0
	 *
	 * @param $name
	 */
	public function init($name = '') {

		/**
		 * Font-awesome updated in elementor 2.6
		 */
		$elementor_version = get_option('elementor_version');

		if(version_compare($elementor_version, '2.6.0', '>=')) {

			if($this->force_update || get_option(self::OK_FA4_TO_5_FLAG, 'no') !== 'yes') {

				$theme = get_option('stylesheet', '');
				//if($theme == $name) {}

				$customizer_opt       = 'theme_mods_' . $theme;
				$customizer_opt_child = 'theme_mods_' . $theme . '-child';


				$opt1 = get_option($customizer_opt);

				/**
				 * Lets back it up first
				 * Then convert it and save it
				 */
				update_option($this->get_back_up_option_key($customizer_opt), $opt1);
				update_option($customizer_opt, $this->convert_fa4_to_fa5($opt1));


				/**
				 * For optimization reason using the same variable
				 * And again first back it up and then convert it
				 */
				$opt1 = get_option($customizer_opt_child);
				update_option($this->get_back_up_option_key($customizer_opt_child), $opt1);
				update_option($customizer_opt_child, $this->convert_fa4_to_fa5($opt1));

				/**
				 * We have converted the icon data
				 * as well as saved a backup copy of original
				 * Now setting the flag conversion is done, so it does not run every time
				 *
				 */
				update_option(self::OK_FA4_TO_5_FLAG, 'yes');
			}
		}
	}


	/**
	 *
	 * @since 1.0.0
	 *
	 * @param $optArray
	 *
	 * @return mixed
	 */
	public function convert_fa4_to_fa5($optArray) {

		foreach($this->keys() as $lookup_key) {
			foreach($optArray as $key => $setting) {
				if($key . '' == $lookup_key) {
					if(!empty($setting) && is_array($setting)) {
						$optArray[$key] = $this->check_and_update($setting);
					}
				}
			}
		}

		return $optArray;
	}


	/**
	 *
	 * @since 1.0.0
	 *
	 * @param $array
	 *
	 * @return mixed
	 */
	private function check_and_update($array) {

		$condition = $this->update_condition();

		foreach($array as $idx => $fld) {

			$done = false;

			foreach($fld as $name => $value) {

				foreach($condition as $old => $new) {

					if(strpos($value, $old) !== false) {
						$array[$idx][$name] = str_replace($old, $new, $value);
						$done               = true;
						break;
					}
				}

				if($done) {
					break;
				}
			}
		}

		return $array;
	}


	/**
	 *
	 * @since 1.0.0
	 *
	 * @param $key
	 *
	 * @return string
	 */
	private function get_back_up_option_key($key) {

		return $key . $this->backup_key;
	}


	/**
	 *
	 * @since 1.0.0
	 *
	 * @return array
	 */
	public function keys() {

		return [
			'nav_social_links',
			'sidebar_social_icon',
			'footer_social_links',
		];
	}


	/**
	 *
	 * @since 1.0.0
	 *
	 * @return array
	 */
	public function update_condition() {

		return [
			'fa fa-500px'                               => 'fab fa-500px',
			'fa fa-address-book'                        => 'fab fa-address-book',
			'fa fa-address-book-o'                      => 'fab fa-address-book-o',
			'fa fa-address-card'                        => 'fab fa-address-card',
			'fa fa-address-card-o'                      => 'fab fa-address-card-o',
			'fa fa-adjust'                              => 'fab fa-adjust',
			'fa fa-adn'                                 => 'fab fa-adn',
			'fa fa-align-center'                        => 'fab fa-align-center',
			'fa fa-align-justify'                       => 'fab fa-align-justify',
			'fa fa-align-left'                          => 'fab fa-align-left',
			'fa fa-align-right'                         => 'fab fa-align-right',
			'fa fa-amazon'                              => 'fab fa-amazon',
			'fa fa-ambulance'                           => 'fab fa-ambulance',
			'fa fa-american-sign-language-interpreting' => 'fab fa-american-sign-language-interpreting',
			'fa fa-anchor'                              => 'fab fa-anchor',
			'fa fa-android'                             => 'fab fa-android',
			'fa fa-angellist'                           => 'fab fa-angellist',
			'fa fa-angle-double-down'                   => 'fab fa-angle-double-down',
			'fa fa-angle-double-left'                   => 'fab fa-angle-double-left',
			'fa fa-angle-double-right'                  => 'fab fa-angle-double-right',
			'fa fa-angle-double-up'                     => 'fab fa-angle-double-up',
			'fa fa-angle-down'                          => 'fab fa-angle-down',
			'fa fa-angle-left'                          => 'fab fa-angle-left',
			'fa fa-angle-right'                         => 'fab fa-angle-right',
			'fa fa-angle-up'                            => 'fab fa-angle-up',
			'fa fa-apple'                               => 'fab fa-apple',
			'fa fa-archive'                             => 'fab fa-archive',
			'fa fa-area-chart'                          => 'fab fa-area-chart',
			'fa fa-arrow-circle-down'                   => 'fab fa-arrow-circle-down',
			'fa fa-arrow-circle-left'                   => 'fab fa-arrow-circle-left',
			'fa fa-arrow-circle-o-down'                 => 'fab fa-arrow-circle-o-down',
			'fa fa-arrow-circle-o-left'                 => 'fab fa-arrow-circle-o-left',
			'fa fa-arrow-circle-o-right'                => 'fab fa-arrow-circle-o-right',
			'fa fa-arrow-circle-o-up'                   => 'fab fa-arrow-circle-o-up',
			'fa fa-arrow-circle-right'                  => 'fab fa-arrow-circle-right',
			'fa fa-arrow-circle-up'                     => 'fab fa-arrow-circle-up',
			'fa fa-arrow-down'                          => 'fab fa-arrow-down',
			'fa fa-arrow-left'                          => 'fab fa-arrow-left',
			'fa fa-arrow-right'                         => 'fab fa-arrow-right',
			'fa fa-arrow-up'                            => 'fab fa-arrow-up',
			'fa fa-arrows'                              => 'fab fa-arrows',
			'fa fa-arrows-alt'                          => 'fab fa-arrows-alt',
			'fa fa-arrows-h'                            => 'fab fa-arrows-h',
			'fa fa-arrows-v'                            => 'fab fa-arrows-v',
			'fa fa-asl-interpreting'                    => 'fab fa-asl-interpreting',
			'fa fa-assistive-listening-systems'         => 'fab fa-assistive-listening-systems',
			'fa fa-asterisk'                            => 'fab fa-asterisk',
			'fa fa-at'                                  => 'fab fa-at',
			'fa fa-audio-description'                   => 'fab fa-audio-description',
			'fa fa-automobile'                          => 'fab fa-automobile',
			'fa fa-backward'                            => 'fab fa-backward',
			'fa fa-balance-scale'                       => 'fab fa-balance-scale',
			'fa fa-ban'                                 => 'fab fa-ban',
			'fa fa-bandcamp'                            => 'fab fa-bandcamp',
			'fa fa-bank'                                => 'fab fa-bank',
			'fa fa-bar-chart'                           => 'fab fa-bar-chart',
			'fa fa-bar-chart-o'                         => 'fab fa-bar-chart-o',
			'fa fa-barcode'                             => 'fab fa-barcode',
			'fa fa-bars'                                => 'fab fa-bars',
			'fa fa-bath'                                => 'fab fa-bath',
			'fa fa-bathtub'                             => 'fab fa-bathtub',
			'fa fa-battery'                             => 'fab fa-battery',
			'fa fa-battery-0'                           => 'fab fa-battery-0',
			'fa fa-battery-1'                           => 'fab fa-battery-1',
			'fa fa-battery-2'                           => 'fab fa-battery-2',
			'fa fa-battery-3'                           => 'fab fa-battery-3',
			'fa fa-battery-4'                           => 'fab fa-battery-4',
			'fa fa-battery-empty'                       => 'fab fa-battery-empty',
			'fa fa-battery-full'                        => 'fab fa-battery-full',
			'fa fa-battery-half'                        => 'fab fa-battery-half',
			'fa fa-battery-quarter'                     => 'fab fa-battery-quarter',
			'fa fa-battery-three-quarters'              => 'fab fa-battery-three-quarters',
			'fa fa-bed'                                 => 'fab fa-bed',
			'fa fa-beer'                                => 'fab fa-beer',
			'fa fa-behance'                             => 'fab fa-behance',
			'fa fa-behance-square'                      => 'fab fa-behance-square',
			'fa fa-bell'                                => 'fab fa-bell',
			'fa fa-bell-o'                              => 'fab fa-bell-o',
			'fa fa-bell-slash'                          => 'fab fa-bell-slash',
			'fa fa-bell-slash-o'                        => 'fab fa-bell-slash-o',
			'fa fa-bicycle'                             => 'fab fa-bicycle',
			'fa fa-binoculars'                          => 'fab fa-binoculars',
			'fa fa-birthday-cake'                       => 'fab fa-birthday-cake',
			'fa fa-bitbucket'                           => 'fab fa-bitbucket',
			'fa fa-bitbucket-square'                    => 'fab fa-bitbucket-square',
			'fa fa-bitcoin'                             => 'fab fa-bitcoin',
			'fa fa-black-tie'                           => 'fab fa-black-tie',
			'fa fa-blind'                               => 'fab fa-blind',
			'fa fa-bluetooth'                           => 'fab fa-bluetooth',
			'fa fa-bluetooth-b'                         => 'fab fa-bluetooth-b',
			'fa fa-bold'                                => 'fab fa-bold',
			'fa fa-bolt'                                => 'fab fa-bolt',
			'fa fa-bomb'                                => 'fab fa-bomb',
			'fa fa-book'                                => 'fab fa-book',
			'fa fa-bookmark'                            => 'fab fa-bookmark',
			'fa fa-bookmark-o'                          => 'fab fa-bookmark-o',
			'fa fa-braille'                             => 'fab fa-braille',
			'fa fa-briefcase'                           => 'fab fa-briefcase',
			'fa fa-btc'                                 => 'fab fa-btc',
			'fa fa-bug'                                 => 'fab fa-bug',
			'fa fa-building'                            => 'fab fa-building',
			'fa fa-building-o'                          => 'fab fa-building-o',
			'fa fa-bullhorn'                            => 'fab fa-bullhorn',
			'fa fa-bullseye'                            => 'fab fa-bullseye',
			'fa fa-bus'                                 => 'fab fa-bus',
			'fa fa-buysellads'                          => 'fab fa-buysellads',
			'fa fa-cab'                                 => 'fab fa-cab',
			'fa fa-calculator'                          => 'fab fa-calculator',
			'fa fa-calendar'                            => 'fab fa-calendar',
			'fa fa-calendar-check-o'                    => 'fab fa-calendar-check-o',
			'fa fa-calendar-minus-o'                    => 'fab fa-calendar-minus-o',
			'fa fa-calendar-o'                          => 'fab fa-calendar-o',
			'fa fa-calendar-plus-o'                     => 'fab fa-calendar-plus-o',
			'fa fa-calendar-times-o'                    => 'fab fa-calendar-times-o',
			'fa fa-camera'                              => 'fab fa-camera',
			'fa fa-camera-retro'                        => 'fab fa-camera-retro',
			'fa fa-car'                                 => 'fab fa-car',
			'fa fa-caret-down'                          => 'fab fa-caret-down',
			'fa fa-caret-left'                          => 'fab fa-caret-left',
			'fa fa-caret-right'                         => 'fab fa-caret-right',
			'fa fa-caret-square-o-down'                 => 'fab fa-caret-square-o-down',
			'fa fa-caret-square-o-left'                 => 'fab fa-caret-square-o-left',
			'fa fa-caret-square-o-right'                => 'fab fa-caret-square-o-right',
			'fa fa-caret-square-o-up'                   => 'fab fa-caret-square-o-up',
			'fa fa-caret-up'                            => 'fab fa-caret-up',
			'fa fa-cart-arrow-down'                     => 'fab fa-cart-arrow-down',
			'fa fa-cart-plus'                           => 'fab fa-cart-plus',
			'fa fa-cc'                                  => 'fab fa-cc',
			'fa fa-cc-amex'                             => 'fab fa-cc-amex',
			'fa fa-cc-diners-club'                      => 'fab fa-cc-diners-club',
			'fa fa-cc-discover'                         => 'fab fa-cc-discover',
			'fa fa-cc-jcb'                              => 'fab fa-cc-jcb',
			'fa fa-cc-mastercard'                       => 'fab fa-cc-mastercard',
			'fa fa-cc-paypal'                           => 'fab fa-cc-paypal',
			'fa fa-cc-stripe'                           => 'fab fa-cc-stripe',
			'fa fa-cc-visa'                             => 'fab fa-cc-visa',
			'fa fa-certificate'                         => 'fab fa-certificate',
			'fa fa-chain'                               => 'fab fa-chain',
			'fa fa-chain-broken'                        => 'fab fa-chain-broken',
			'fa fa-check'                               => 'fab fa-check',
			'fa fa-check-circle'                        => 'fab fa-check-circle',
			'fa fa-check-circle-o'                      => 'fab fa-check-circle-o',
			'fa fa-check-square'                        => 'fab fa-check-square',
			'fa fa-check-square-o'                      => 'fab fa-check-square-o',
			'fa fa-chevron-circle-down'                 => 'fab fa-chevron-circle-down',
			'fa fa-chevron-circle-left'                 => 'fab fa-chevron-circle-left',
			'fa fa-chevron-circle-right'                => 'fab fa-chevron-circle-right',
			'fa fa-chevron-circle-up'                   => 'fab fa-chevron-circle-up',
			'fa fa-chevron-down'                        => 'fab fa-chevron-down',
			'fa fa-chevron-left'                        => 'fab fa-chevron-left',
			'fa fa-chevron-right'                       => 'fab fa-chevron-right',
			'fa fa-chevron-up'                          => 'fab fa-chevron-up',
			'fa fa-child'                               => 'fab fa-child',
			'fa fa-chrome'                              => 'fab fa-chrome',
			'fa fa-circle'                              => 'fab fa-circle',
			'fa fa-circle-o'                            => 'fab fa-circle-o',
			'fa fa-circle-o-notch'                      => 'fab fa-circle-o-notch',
			'fa fa-circle-thin'                         => 'fab fa-circle-thin',
			'fa fa-clipboard'                           => 'fab fa-clipboard',
			'fa fa-clock-o'                             => 'fab fa-clock-o',
			'fa fa-clone'                               => 'fab fa-clone',
			'fa fa-close'                               => 'fab fa-close',
			'fa fa-cloud'                               => 'fab fa-cloud',
			'fa fa-cloud-download'                      => 'fab fa-cloud-download',
			'fa fa-cloud-upload'                        => 'fab fa-cloud-upload',
			'fa fa-cny'                                 => 'fab fa-cny',
			'fa fa-code'                                => 'fab fa-code',
			'fa fa-code-fork'                           => 'fab fa-code-fork',
			'fa fa-codepen'                             => 'fab fa-codepen',
			'fa fa-codiepie'                            => 'fab fa-codiepie',
			'fa fa-coffee'                              => 'fab fa-coffee',
			'fa fa-cog'                                 => 'fab fa-cog',
			'fa fa-cogs'                                => 'fab fa-cogs',
			'fa fa-columns'                             => 'fab fa-columns',
			'fa fa-comment'                             => 'fab fa-comment',
			'fa fa-comment-o'                           => 'fab fa-comment-o',
			'fa fa-commenting'                          => 'fab fa-commenting',
			'fa fa-commenting-o'                        => 'fab fa-commenting-o',
			'fa fa-comments'                            => 'fab fa-comments',
			'fa fa-comments-o'                          => 'fab fa-comments-o',
			'fa fa-compass'                             => 'fab fa-compass',
			'fa fa-compress'                            => 'fab fa-compress',
			'fa fa-connectdevelop'                      => 'fab fa-connectdevelop',
			'fa fa-contao'                              => 'fab fa-contao',
			'fa fa-copy'                                => 'fab fa-copy',
			'fa fa-copyright'                           => 'fab fa-copyright',
			'fa fa-creative-commons'                    => 'fab fa-creative-commons',
			'fa fa-credit-card'                         => 'fab fa-credit-card',
			'fa fa-credit-card-alt'                     => 'fab fa-credit-card-alt',
			'fa fa-crop'                                => 'fab fa-crop',
			'fa fa-crosshairs'                          => 'fab fa-crosshairs',
			'fa fa-css3'                                => 'fab fa-css3',
			'fa fa-cube'                                => 'fab fa-cube',
			'fa fa-cubes'                               => 'fab fa-cubes',
			'fa fa-cut'                                 => 'fab fa-cut',
			'fa fa-cutlery'                             => 'fab fa-cutlery',
			'fa fa-dashboard'                           => 'fab fa-dashboard',
			'fa fa-dashcube'                            => 'fab fa-dashcube',
			'fa fa-database'                            => 'fab fa-database',
			'fa fa-deaf'                                => 'fab fa-deaf',
			'fa fa-deafness'                            => 'fab fa-deafness',
			'fa fa-dedent'                              => 'fab fa-dedent',
			'fa fa-delicious'                           => 'fab fa-delicious',
			'fa fa-desktop'                             => 'fab fa-desktop',
			'fa fa-deviantart'                          => 'fab fa-deviantart',
			'fa fa-diamond'                             => 'fab fa-diamond',
			'fa fa-digg'                                => 'fab fa-digg',
			'fa fa-dollar'                              => 'fab fa-dollar',
			'fa fa-dot-circle-o'                        => 'fab fa-dot-circle-o',
			'fa fa-download'                            => 'fab fa-download',
			'fa fa-dribbble'                            => 'fab fa-dribbble',
			'fa fa-drivers-license'                     => 'fab fa-drivers-license',
			'fa fa-drivers-license-o'                   => 'fab fa-drivers-license-o',
			'fa fa-dropbox'                             => 'fab fa-dropbox',
			'fa fa-drupal'                              => 'fab fa-drupal',
			'fa fa-edge'                                => 'fab fa-edge',
			'fa fa-edit'                                => 'fab fa-edit',
			'fa fa-eercast'                             => 'fab fa-eercast',
			'fa fa-eject'                               => 'fab fa-eject',
			'fa fa-ellipsis-h'                          => 'fab fa-ellipsis-h',
			'fa fa-ellipsis-v'                          => 'fab fa-ellipsis-v',
			'fa fa-empire'                              => 'fab fa-empire',
			'fa fa-envelope'                            => 'fab fa-envelope',
			'fa fa-envelope-o'                          => 'fab fa-envelope-o',
			'fa fa-envelope-open'                       => 'fab fa-envelope-open',
			'fa fa-envelope-open-o'                     => 'fab fa-envelope-open-o',
			'fa fa-envelope-square'                     => 'fab fa-envelope-square',
			'fa fa-envira'                              => 'fab fa-envira',
			'fa fa-eraser'                              => 'fab fa-eraser',
			'fa fa-etsy'                                => 'fab fa-etsy',
			'fa fa-eur'                                 => 'fab fa-eur',
			'fa fa-euro'                                => 'fab fa-euro',
			'fa fa-exchange'                            => 'fab fa-exchange',
			'fa fa-exclamation'                         => 'fab fa-exclamation',
			'fa fa-exclamation-circle'                  => 'fab fa-exclamation-circle',
			'fa fa-exclamation-triangle'                => 'fab fa-exclamation-triangle',
			'fa fa-expand'                              => 'fab fa-expand',
			'fa fa-expeditedssl'                        => 'fab fa-expeditedssl',
			'fa fa-external-link'                       => 'fab fa-external-link',
			'fa fa-external-link-square'                => 'fab fa-external-link-square',
			'fa fa-eye'                                 => 'fab fa-eye',
			'fa fa-eye-slash'                           => 'fab fa-eye-slash',
			'fa fa-eyedropper'                          => 'fab fa-eyedropper',
			'fa fa-fa'                                  => 'fab fa-fa',
			'fa fa-facebook'                            => 'fab fa-facebook',
			'fa fa-facebook-f'                          => 'fab fa-facebook-f',
			'fa fa-facebook-official'                   => 'fab fa-facebook-official',
			'fa fa-facebook-square'                     => 'fab fa-facebook-square',
			'fa fa-fast-backward'                       => 'fab fa-fast-backward',
			'fa fa-fast-forward'                        => 'fab fa-fast-forward',
			'fa fa-fax'                                 => 'fab fa-fax',
			'fa fa-feed'                                => 'fab fa-feed',
			'fa fa-female'                              => 'fab fa-female',
			'fa fa-fighter-jet'                         => 'fab fa-fighter-jet',
			'fa fa-file'                                => 'fab fa-file',
			'fa fa-file-archive-o'                      => 'fab fa-file-archive-o',
			'fa fa-file-audio-o'                        => 'fab fa-file-audio-o',
			'fa fa-file-code-o'                         => 'fab fa-file-code-o',
			'fa fa-file-excel-o'                        => 'fab fa-file-excel-o',
			'fa fa-file-image-o'                        => 'fab fa-file-image-o',
			'fa fa-file-movie-o'                        => 'fab fa-file-movie-o',
			'fa fa-file-o'                              => 'fab fa-file-o',
			'fa fa-file-pdf-o'                          => 'fab fa-file-pdf-o',
			'fa fa-file-photo-o'                        => 'fab fa-file-photo-o',
			'fa fa-file-picture-o'                      => 'fab fa-file-picture-o',
			'fa fa-file-powerpoint-o'                   => 'fab fa-file-powerpoint-o',
			'fa fa-file-sound-o'                        => 'fab fa-file-sound-o',
			'fa fa-file-text'                           => 'fab fa-file-text',
			'fa fa-file-text-o'                         => 'fab fa-file-text-o',
			'fa fa-file-video-o'                        => 'fab fa-file-video-o',
			'fa fa-file-word-o'                         => 'fab fa-file-word-o',
			'fa fa-file-zip-o'                          => 'fab fa-file-zip-o',
			'fa fa-files-o'                             => 'fab fa-files-o',
			'fa fa-film'                                => 'fab fa-film',
			'fa fa-filter'                              => 'fab fa-filter',
			'fa fa-fire'                                => 'fab fa-fire',
			'fa fa-fire-extinguisher'                   => 'fab fa-fire-extinguisher',
			'fa fa-firefox'                             => 'fab fa-firefox',
			'fa fa-first-order'                         => 'fab fa-first-order',
			'fa fa-flag'                                => 'fab fa-flag',
			'fa fa-flag-checkered'                      => 'fab fa-flag-checkered',
			'fa fa-flag-o'                              => 'fab fa-flag-o',
			'fa fa-flash'                               => 'fab fa-flash',
			'fa fa-flask'                               => 'fab fa-flask',
			'fa fa-flickr'                              => 'fab fa-flickr',
			'fa fa-floppy-o'                            => 'fab fa-floppy-o',
			'fa fa-folder'                              => 'fab fa-folder',
			'fa fa-folder-o'                            => 'fab fa-folder-o',
			'fa fa-folder-open'                         => 'fab fa-folder-open',
			'fa fa-folder-open-o'                       => 'fab fa-folder-open-o',
			'fa fa-font'                                => 'fab fa-font',
			'fa fa-font-awesome'                        => 'fab fa-font-awesome',
			'fa fa-fonticons'                           => 'fab fa-fonticons',
			'fa fa-fort-awesome'                        => 'fab fa-fort-awesome',
			'fa fa-forumbee'                            => 'fab fa-forumbee',
			'fa fa-forward'                             => 'fab fa-forward',
			'fa fa-foursquare'                          => 'fab fa-foursquare',
			'fa fa-free-code-camp'                      => 'fab fa-free-code-camp',
			'fa fa-frown-o'                             => 'fab fa-frown-o',
			'fa fa-futbol-o'                            => 'fab fa-futbol-o',
			'fa fa-gamepad'                             => 'fab fa-gamepad',
			'fa fa-gavel'                               => 'fab fa-gavel',
			'fa fa-gbp'                                 => 'fab fa-gbp',
			'fa fa-ge'                                  => 'fab fa-ge',
			'fa fa-gear'                                => 'fab fa-gear',
			'fa fa-gears'                               => 'fab fa-gears',
			'fa fa-genderless'                          => 'fab fa-genderless',
			'fa fa-get-pocket'                          => 'fab fa-get-pocket',
			'fa fa-gg'                                  => 'fab fa-gg',
			'fa fa-gg-circle'                           => 'fab fa-gg-circle',
			'fa fa-gift'                                => 'fab fa-gift',
			'fa fa-git'                                 => 'fab fa-git',
			'fa fa-git-square'                          => 'fab fa-git-square',
			'fa fa-github'                              => 'fab fa-github',
			'fa fa-github-alt'                          => 'fab fa-github-alt',
			'fa fa-github-square'                       => 'fab fa-github-square',
			'fa fa-gitlab'                              => 'fab fa-gitlab',
			'fa fa-gittip'                              => 'fab fa-gittip',
			'fa fa-glass'                               => 'fab fa-glass',
			'fa fa-glide'                               => 'fab fa-glide',
			'fa fa-glide-g'                             => 'fab fa-glide-g',
			'fa fa-globe'                               => 'fab fa-globe',
			'fa fa-google'                              => 'fab fa-google',
			'fa fa-google-plus'                         => 'fab fa-google-plus-g',
			'fa fa-google-plus-circle'                  => 'fab fa-google-plus-circle',
			'fa fa-google-plus-official'                => 'fab fa-google-plus-official',
			'fa fa-google-plus-square'                  => 'fab fa-google-plus-square',
			'fa fa-google-wallet'                       => 'fab fa-google-wallet',
			'fa fa-graduation-cap'                      => 'fab fa-graduation-cap',
			'fa fa-gratipay'                            => 'fab fa-gratipay',
			'fa fa-grav'                                => 'fab fa-grav',
			'fa fa-group'                               => 'fab fa-group',
			'fa fa-h-square'                            => 'fab fa-h-square',
			'fa fa-hacker-news'                         => 'fab fa-hacker-news',
			'fa fa-hand-grab-o'                         => 'fab fa-hand-grab-o',
			'fa fa-hand-lizard-o'                       => 'fab fa-hand-lizard-o',
			'fa fa-hand-o-down'                         => 'fab fa-hand-o-down',
			'fa fa-hand-o-left'                         => 'fab fa-hand-o-left',
			'fa fa-hand-o-right'                        => 'fab fa-hand-o-right',
			'fa fa-hand-o-up'                           => 'fab fa-hand-o-up',
			'fa fa-hand-paper-o'                        => 'fab fa-hand-paper-o',
			'fa fa-hand-peace-o'                        => 'fab fa-hand-peace-o',
			'fa fa-hand-pointer-o'                      => 'fab fa-hand-pointer-o',
			'fa fa-hand-rock-o'                         => 'fab fa-hand-rock-o',
			'fa fa-hand-scissors-o'                     => 'fab fa-hand-scissors-o',
			'fa fa-hand-spock-o'                        => 'fab fa-hand-spock-o',
			'fa fa-hand-stop-o'                         => 'fab fa-hand-stop-o',
			'fa fa-handshake-o'                         => 'fab fa-handshake-o',
			'fa fa-hard-of-hearing'                     => 'fab fa-hard-of-hearing',
			'fa fa-hashtag'                             => 'fab fa-hashtag',
			'fa fa-hdd-o'                               => 'fab fa-hdd-o',
			'fa fa-header'                              => 'fab fa-header',
			'fa fa-headphones'                          => 'fab fa-headphones',
			'fa fa-heart'                               => 'fab fa-heart',
			'fa fa-heart-o'                             => 'fab fa-heart-o',
			'fa fa-heartbeat'                           => 'fab fa-heartbeat',
			'fa fa-history'                             => 'fab fa-history',
			'fa fa-home'                                => 'fab fa-home',
			'fa fa-hospital-o'                          => 'fab fa-hospital-o',
			'fa fa-hotel'                               => 'fab fa-hotel',
			'fa fa-hourglass'                           => 'fab fa-hourglass',
			'fa fa-hourglass-1'                         => 'fab fa-hourglass-1',
			'fa fa-hourglass-2'                         => 'fab fa-hourglass-2',
			'fa fa-hourglass-3'                         => 'fab fa-hourglass-3',
			'fa fa-hourglass-end'                       => 'fab fa-hourglass-end',
			'fa fa-hourglass-half'                      => 'fab fa-hourglass-half',
			'fa fa-hourglass-o'                         => 'fab fa-hourglass-o',
			'fa fa-hourglass-start'                     => 'fab fa-hourglass-start',
			'fa fa-houzz'                               => 'fab fa-houzz',
			'fa fa-html5'                               => 'fab fa-html5',
			'fa fa-i-cursor'                            => 'fab fa-i-cursor',
			'fa fa-id-badge'                            => 'fab fa-id-badge',
			'fa fa-id-card'                             => 'fab fa-id-card',
			'fa fa-id-card-o'                           => 'fab fa-id-card-o',
			'fa fa-ils'                                 => 'fab fa-ils',
			'fa fa-image'                               => 'fab fa-image',
			'fa fa-imdb'                                => 'fab fa-imdb',
			'fa fa-inbox'                               => 'fab fa-inbox',
			'fa fa-indent'                              => 'fab fa-indent',
			'fa fa-industry'                            => 'fab fa-industry',
			'fa fa-info'                                => 'fab fa-info',
			'fa fa-info-circle'                         => 'fab fa-info-circle',
			'fa fa-inr'                                 => 'fab fa-inr',
			'fa fa-instagram'                           => 'fab fa-instagram',
			'fa fa-institution'                         => 'fab fa-institution',
			'fa fa-internet-explorer'                   => 'fab fa-internet-explorer',
			'fa fa-intersex'                            => 'fab fa-intersex',
			'fa fa-ioxhost'                             => 'fab fa-ioxhost',
			'fa fa-italic'                              => 'fab fa-italic',
			'fa fa-joomla'                              => 'fab fa-joomla',
			'fa fa-jpy'                                 => 'fab fa-jpy',
			'fa fa-jsfiddle'                            => 'fab fa-jsfiddle',
			'fa fa-key'                                 => 'fab fa-key',
			'fa fa-keyboard-o'                          => 'fab fa-keyboard-o',
			'fa fa-krw'                                 => 'fab fa-krw',
			'fa fa-language'                            => 'fab fa-language',
			'fa fa-laptop'                              => 'fab fa-laptop',
			'fa fa-lastfm'                              => 'fab fa-lastfm',
			'fa fa-lastfm-square'                       => 'fab fa-lastfm-square',
			'fa fa-leaf'                                => 'fab fa-leaf',
			'fa fa-leanpub'                             => 'fab fa-leanpub',
			'fa fa-legal'                               => 'fab fa-legal',
			'fa fa-lemon-o'                             => 'fab fa-lemon-o',
			'fa fa-level-down'                          => 'fab fa-level-down',
			'fa fa-level-up'                            => 'fab fa-level-up',
			'fa fa-life-bouy'                           => 'fab fa-life-bouy',
			'fa fa-life-buoy'                           => 'fab fa-life-buoy',
			'fa fa-life-ring'                           => 'fab fa-life-ring',
			'fa fa-life-saver'                          => 'fab fa-life-saver',
			'fa fa-lightbulb-o'                         => 'fab fa-lightbulb-o',
			'fa fa-line-chart'                          => 'fab fa-line-chart',
			'fa fa-link'                                => 'fab fa-link',
			'fa fa-linkedin'                            => 'fab fa-linkedin',
			'fa fa-linkedin-square'                     => 'fab fa-linkedin-square',
			'fa fa-linode'                              => 'fab fa-linode',
			'fa fa-linux'                               => 'fab fa-linux',
			'fa fa-list'                                => 'fab fa-list',
			'fa fa-list-alt'                            => 'fab fa-list-alt',
			'fa fa-list-ol'                             => 'fab fa-list-ol',
			'fa fa-list-ul'                             => 'fab fa-list-ul',
			'fa fa-location-arrow'                      => 'fab fa-location-arrow',
			'fa fa-lock'                                => 'fab fa-lock',
			'fa fa-long-arrow-down'                     => 'fab fa-long-arrow-down',
			'fa fa-long-arrow-left'                     => 'fab fa-long-arrow-left',
			'fa fa-long-arrow-right'                    => 'fab fa-long-arrow-right',
			'fa fa-long-arrow-up'                       => 'fab fa-long-arrow-up',
			'fa fa-low-vision'                          => 'fab fa-low-vision',
			'fa fa-magic'                               => 'fab fa-magic',
			'fa fa-magnet'                              => 'fab fa-magnet',
			'fa fa-mail-forward'                        => 'fab fa-mail-forward',
			'fa fa-mail-reply'                          => 'fab fa-mail-reply',
			'fa fa-mail-reply-all'                      => 'fab fa-mail-reply-all',
			'fa fa-male'                                => 'fab fa-male',
			'fa fa-map'                                 => 'fab fa-map',
			'fa fa-map-marker'                          => 'fab fa-map-marker',
			'fa fa-map-o'                               => 'fab fa-map-o',
			'fa fa-map-pin'                             => 'fab fa-map-pin',
			'fa fa-map-signs'                           => 'fab fa-map-signs',
			'fa fa-mars'                                => 'fab fa-mars',
			'fa fa-mars-double'                         => 'fab fa-mars-double',
			'fa fa-mars-stroke'                         => 'fab fa-mars-stroke',
			'fa fa-mars-stroke-h'                       => 'fab fa-mars-stroke-h',
			'fa fa-mars-stroke-v'                       => 'fab fa-mars-stroke-v',
			'fa fa-maxcdn'                              => 'fab fa-maxcdn',
			'fa fa-meanpath'                            => 'fab fa-meanpath',
			'fa fa-medium'                              => 'fab fa-medium',
			'fa fa-medkit'                              => 'fab fa-medkit',
			'fa fa-meetup'                              => 'fab fa-meetup',
			'fa fa-meh-o'                               => 'fab fa-meh-o',
			'fa fa-mercury'                             => 'fab fa-mercury',
			'fa fa-microchip'                           => 'fab fa-microchip',
			'fa fa-microphone'                          => 'fab fa-microphone',
			'fa fa-microphone-slash'                    => 'fab fa-microphone-slash',
			'fa fa-minus'                               => 'fab fa-minus',
			'fa fa-minus-circle'                        => 'fab fa-minus-circle',
			'fa fa-minus-square'                        => 'fab fa-minus-square',
			'fa fa-minus-square-o'                      => 'fab fa-minus-square-o',
			'fa fa-mixcloud'                            => 'fab fa-mixcloud',
			'fa fa-mobile'                              => 'fab fa-mobile',
			'fa fa-mobile-phone'                        => 'fab fa-mobile-phone',
			'fa fa-modx'                                => 'fab fa-modx',
			'fa fa-money'                               => 'fab fa-money',
			'fa fa-moon-o'                              => 'fab fa-moon-o',
			'fa fa-mortar-board'                        => 'fab fa-mortar-board',
			'fa fa-motorcycle'                          => 'fab fa-motorcycle',
			'fa fa-mouse-pointer'                       => 'fab fa-mouse-pointer',
			'fa fa-music'                               => 'fab fa-music',
			'fa fa-navicon'                             => 'fab fa-navicon',
			'fa fa-neuter'                              => 'fab fa-neuter',
			'fa fa-newspaper-o'                         => 'fab fa-newspaper-o',
			'fa fa-object-group'                        => 'fab fa-object-group',
			'fa fa-object-ungroup'                      => 'fab fa-object-ungroup',
			'fa fa-odnoklassniki'                       => 'fab fa-odnoklassniki',
			'fa fa-odnoklassniki-square'                => 'fab fa-odnoklassniki-square',
			'fa fa-opencart'                            => 'fab fa-opencart',
			'fa fa-openid'                              => 'fab fa-openid',
			'fa fa-opera'                               => 'fab fa-opera',
			'fa fa-optin-monster'                       => 'fab fa-optin-monster',
			'fa fa-outdent'                             => 'fab fa-outdent',
			'fa fa-pagelines'                           => 'fab fa-pagelines',
			'fa fa-paint-brush'                         => 'fab fa-paint-brush',
			'fa fa-paper-plane'                         => 'fab fa-paper-plane',
			'fa fa-paper-plane-o'                       => 'fab fa-paper-plane-o',
			'fa fa-paperclip'                           => 'fab fa-paperclip',
			'fa fa-paragraph'                           => 'fab fa-paragraph',
			'fa fa-paste'                               => 'fab fa-paste',
			'fa fa-pause'                               => 'fab fa-pause',
			'fa fa-pause-circle'                        => 'fab fa-pause-circle',
			'fa fa-pause-circle-o'                      => 'fab fa-pause-circle-o',
			'fa fa-paw'                                 => 'fab fa-paw',
			'fa fa-paypal'                              => 'fab fa-paypal',
			'fa fa-pencil'                              => 'fab fa-pencil',
			'fa fa-pencil-square'                       => 'fab fa-pencil-square',
			'fa fa-pencil-square-o'                     => 'fab fa-pencil-square-o',
			'fa fa-percent'                             => 'fab fa-percent',
			'fa fa-phone'                               => 'fab fa-phone',
			'fa fa-phone-square'                        => 'fab fa-phone-square',
			'fa fa-photo'                               => 'fab fa-photo',
			'fa fa-picture-o'                           => 'fab fa-picture-o',
			'fa fa-pie-chart'                           => 'fab fa-pie-chart',
			'fa fa-pied-piper'                          => 'fab fa-pied-piper',
			'fa fa-pied-piper-alt'                      => 'fab fa-pied-piper-alt',
			'fa fa-pied-piper-pp'                       => 'fab fa-pied-piper-pp',
			'fa fa-pinterest'                           => 'fab fa-pinterest',
			'fa fa-pinterest-p'                         => 'fab fa-pinterest-p',
			'fa fa-pinterest-square'                    => 'fab fa-pinterest-square',
			'fa fa-plane'                               => 'fab fa-plane',
			'fa fa-play'                                => 'fab fa-play',
			'fa fa-play-circle'                         => 'fab fa-play-circle',
			'fa fa-play-circle-o'                       => 'fab fa-play-circle-o',
			'fa fa-plug'                                => 'fab fa-plug',
			'fa fa-plus'                                => 'fab fa-plus',
			'fa fa-plus-circle'                         => 'fab fa-plus-circle',
			'fa fa-plus-square'                         => 'fab fa-plus-square',
			'fa fa-plus-square-o'                       => 'fab fa-plus-square-o',
			'fa fa-podcast'                             => 'fab fa-podcast',
			'fa fa-power-off'                           => 'fab fa-power-off',
			'fa fa-print'                               => 'fab fa-print',
			'fa fa-product-hunt'                        => 'fab fa-product-hunt',
			'fa fa-pull-left'                           => 'fab fa-pull-left',
			'fa fa-pull-right'                          => 'fab fa-pull-right',
			'fa fa-puzzle-piece'                        => 'fab fa-puzzle-piece',
			'fa fa-qq'                                  => 'fab fa-qq',
			'fa fa-qrcode'                              => 'fab fa-qrcode',
			'fa fa-question'                            => 'fab fa-question',
			'fa fa-question-circle'                     => 'fab fa-question-circle',
			'fa fa-question-circle-o'                   => 'fab fa-question-circle-o',
			'fa fa-quora'                               => 'fab fa-quora',
			'fa fa-quote-left'                          => 'fab fa-quote-left',
			'fa fa-quote-right'                         => 'fab fa-quote-right',
			'fa fa-ra'                                  => 'fab fa-ra',
			'fa fa-random'                              => 'fab fa-random',
			'fa fa-ravelry'                             => 'fab fa-ravelry',
			'fa fa-rebel'                               => 'fab fa-rebel',
			'fa fa-recycle'                             => 'fab fa-recycle',
			'fa fa-reddit'                              => 'fab fa-reddit',
			'fa fa-reddit-alien'                        => 'fab fa-reddit-alien',
			'fa fa-reddit-square'                       => 'fab fa-reddit-square',
			'fa fa-refresh'                             => 'fab fa-refresh',
			'fa fa-registered'                          => 'fab fa-registered',
			'fa fa-remove'                              => 'fab fa-remove',
			'fa fa-renren'                              => 'fab fa-renren',
			'fa fa-reorder'                             => 'fab fa-reorder',
			'fa fa-repeat'                              => 'fab fa-repeat',
			'fa fa-reply'                               => 'fab fa-reply',
			'fa fa-reply-all'                           => 'fab fa-reply-all',
			'fa fa-resistance'                          => 'fab fa-resistance',
			'fa fa-retweet'                             => 'fab fa-retweet',
			'fa fa-rmb'                                 => 'fab fa-rmb',
			'fa fa-road'                                => 'fab fa-road',
			'fa fa-rocket'                              => 'fab fa-rocket',
			'fa fa-rotate-left'                         => 'fab fa-rotate-left',
			'fa fa-rotate-right'                        => 'fab fa-rotate-right',
			'fa fa-rouble'                              => 'fab fa-rouble',
			'fa fa-rss'                                 => 'fab fa-rss',
			'fa fa-rss-square'                          => 'fab fa-rss-square',
			'fa fa-rub'                                 => 'fab fa-rub',
			'fa fa-ruble'                               => 'fab fa-ruble',
			'fa fa-rupee'                               => 'fab fa-rupee',
			'fa fa-s15'                                 => 'fab fa-s15',
			'fa fa-safari'                              => 'fab fa-safari',
			'fa fa-save'                                => 'fab fa-save',
			'fa fa-scissors'                            => 'fab fa-scissors',
			'fa fa-scribd'                              => 'fab fa-scribd',
			'fa fa-search'                              => 'fab fa-search',
			'fa fa-search-minus'                        => 'fab fa-search-minus',
			'fa fa-search-plus'                         => 'fab fa-search-plus',
			'fa fa-sellsy'                              => 'fab fa-sellsy',
			'fa fa-send'                                => 'fab fa-send',
			'fa fa-send-o'                              => 'fab fa-send-o',
			'fa fa-server'                              => 'fab fa-server',
			'fa fa-share'                               => 'fab fa-share',
			'fa fa-share-alt'                           => 'fab fa-share-alt',
			'fa fa-share-alt-square'                    => 'fab fa-share-alt-square',
			'fa fa-share-square'                        => 'fab fa-share-square',
			'fa fa-share-square-o'                      => 'fab fa-share-square-o',
			'fa fa-shekel'                              => 'fab fa-shekel',
			'fa fa-sheqel'                              => 'fab fa-sheqel',
			'fa fa-shield'                              => 'fab fa-shield',
			'fa fa-ship'                                => 'fab fa-ship',
			'fa fa-shirtsinbulk'                        => 'fab fa-shirtsinbulk',
			'fa fa-shopping-bag'                        => 'fab fa-shopping-bag',
			'fa fa-shopping-basket'                     => 'fab fa-shopping-basket',
			'fa fa-shopping-cart'                       => 'fab fa-shopping-cart',
			'fa fa-shower'                              => 'fab fa-shower',
			'fa fa-sign-in'                             => 'fab fa-sign-in',
			'fa fa-sign-language'                       => 'fab fa-sign-language',
			'fa fa-sign-out'                            => 'fab fa-sign-out',
			'fa fa-signal'                              => 'fab fa-signal',
			'fa fa-signing'                             => 'fab fa-signing',
			'fa fa-simplybuilt'                         => 'fab fa-simplybuilt',
			'fa fa-sitemap'                             => 'fab fa-sitemap',
			'fa fa-skyatlas'                            => 'fab fa-skyatlas',
			'fa fa-skype'                               => 'fab fa-skype',
			'fa fa-slack'                               => 'fab fa-slack',
			'fa fa-sliders'                             => 'fab fa-sliders',
			'fa fa-slideshare'                          => 'fab fa-slideshare',
			'fa fa-smile-o'                             => 'fab fa-smile-o',
			'fa fa-snapchat'                            => 'fab fa-snapchat',
			'fa fa-snapchat-ghost'                      => 'fab fa-snapchat-ghost',
			'fa fa-snapchat-square'                     => 'fab fa-snapchat-square',
			'fa fa-snowflake-o'                         => 'fab fa-snowflake-o',
			'fa fa-soccer-ball-o'                       => 'fab fa-soccer-ball-o',
			'fa fa-sort'                                => 'fab fa-sort',
			'fa fa-sort-alpha-asc'                      => 'fab fa-sort-alpha-asc',
			'fa fa-sort-alpha-desc'                     => 'fab fa-sort-alpha-desc',
			'fa fa-sort-amount-asc'                     => 'fab fa-sort-amount-asc',
			'fa fa-sort-amount-desc'                    => 'fab fa-sort-amount-desc',
			'fa fa-sort-asc'                            => 'fab fa-sort-asc',
			'fa fa-sort-desc'                           => 'fab fa-sort-desc',
			'fa fa-sort-down'                           => 'fab fa-sort-down',
			'fa fa-sort-numeric-asc'                    => 'fab fa-sort-numeric-asc',
			'fa fa-sort-numeric-desc'                   => 'fab fa-sort-numeric-desc',
			'fa fa-sort-up'                             => 'fab fa-sort-up',
			'fa fa-soundcloud'                          => 'fab fa-soundcloud',
			'fa fa-space-shuttle'                       => 'fab fa-space-shuttle',
			'fa fa-spinner'                             => 'fab fa-spinner',
			'fa fa-spoon'                               => 'fab fa-spoon',
			'fa fa-spotify'                             => 'fab fa-spotify',
			'fa fa-square'                              => 'fab fa-square',
			'fa fa-square-o'                            => 'fab fa-square-o',
			'fa fa-stack-exchange'                      => 'fab fa-stack-exchange',
			'fa fa-stack-overflow'                      => 'fab fa-stack-overflow',
			'fa fa-star'                                => 'fab fa-star',
			'fa fa-star-half'                           => 'fab fa-star-half',
			'fa fa-star-half-empty'                     => 'fab fa-star-half-empty',
			'fa fa-star-half-full'                      => 'fab fa-star-half-full',
			'fa fa-star-half-o'                         => 'fab fa-star-half-o',
			'fa fa-star-o'                              => 'fab fa-star-o',
			'fa fa-steam'                               => 'fab fa-steam',
			'fa fa-steam-square'                        => 'fab fa-steam-square',
			'fa fa-step-backward'                       => 'fab fa-step-backward',
			'fa fa-step-forward'                        => 'fab fa-step-forward',
			'fa fa-stethoscope'                         => 'fab fa-stethoscope',
			'fa fa-sticky-note'                         => 'fab fa-sticky-note',
			'fa fa-sticky-note-o'                       => 'fab fa-sticky-note-o',
			'fa fa-stop'                                => 'fab fa-stop',
			'fa fa-stop-circle'                         => 'fab fa-stop-circle',
			'fa fa-stop-circle-o'                       => 'fab fa-stop-circle-o',
			'fa fa-street-view'                         => 'fab fa-street-view',
			'fa fa-strikethrough'                       => 'fab fa-strikethrough',
			'fa fa-stumbleupon'                         => 'fab fa-stumbleupon',
			'fa fa-stumbleupon-circle'                  => 'fab fa-stumbleupon-circle',
			'fa fa-subscript'                           => 'fab fa-subscript',
			'fa fa-subway'                              => 'fab fa-subway',
			'fa fa-suitcase'                            => 'fab fa-suitcase',
			'fa fa-sun-o'                               => 'fab fa-sun-o',
			'fa fa-superpowers'                         => 'fab fa-superpowers',
			'fa fa-superscript'                         => 'fab fa-superscript',
			'fa fa-support'                             => 'fab fa-support',
			'fa fa-table'                               => 'fab fa-table',
			'fa fa-tablet'                              => 'fab fa-tablet',
			'fa fa-tachometer'                          => 'fab fa-tachometer',
			'fa fa-tag'                                 => 'fab fa-tag',
			'fa fa-tags'                                => 'fab fa-tags',
			'fa fa-tasks'                               => 'fab fa-tasks',
			'fa fa-taxi'                                => 'fab fa-taxi',
			'fa fa-telegram'                            => 'fab fa-telegram',
			'fa fa-television'                          => 'fab fa-television',
			'fa fa-tencent-weibo'                       => 'fab fa-tencent-weibo',
			'fa fa-terminal'                            => 'fab fa-terminal',
			'fa fa-text-height'                         => 'fab fa-text-height',
			'fa fa-text-width'                          => 'fab fa-text-width',
			'fa fa-th'                                  => 'fab fa-th',
			'fa fa-th-large'                            => 'fab fa-th-large',
			'fa fa-th-list'                             => 'fab fa-th-list',
			'fa fa-themeisle'                           => 'fab fa-themeisle',
			'fa fa-thermometer'                         => 'fab fa-thermometer',
			'fa fa-thermometer-0'                       => 'fab fa-thermometer-0',
			'fa fa-thermometer-1'                       => 'fab fa-thermometer-1',
			'fa fa-thermometer-2'                       => 'fab fa-thermometer-2',
			'fa fa-thermometer-3'                       => 'fab fa-thermometer-3',
			'fa fa-thermometer-4'                       => 'fab fa-thermometer-4',
			'fa fa-thermometer-empty'                   => 'fab fa-thermometer-empty',
			'fa fa-thermometer-full'                    => 'fab fa-thermometer-full',
			'fa fa-thermometer-half'                    => 'fab fa-thermometer-half',
			'fa fa-thermometer-quarter'                 => 'fab fa-thermometer-quarter',
			'fa fa-thermometer-three-quarters'          => 'fab fa-thermometer-three-quarters',
			'fa fa-thumb-tack'                          => 'fab fa-thumb-tack',
			'fa fa-thumbs-down'                         => 'fab fa-thumbs-down',
			'fa fa-thumbs-o-down'                       => 'fab fa-thumbs-o-down',
			'fa fa-thumbs-o-up'                         => 'fab fa-thumbs-o-up',
			'fa fa-thumbs-up'                           => 'fab fa-thumbs-up',
			'fa fa-ticket'                              => 'fab fa-ticket',
			'fa fa-times'                               => 'fab fa-times',
			'fa fa-times-circle'                        => 'fab fa-times-circle',
			'fa fa-times-circle-o'                      => 'fab fa-times-circle-o',
			'fa fa-times-rectangle'                     => 'fab fa-times-rectangle',
			'fa fa-times-rectangle-o'                   => 'fab fa-times-rectangle-o',
			'fa fa-tint'                                => 'fab fa-tint',
			'fa fa-toggle-down'                         => 'fab fa-toggle-down',
			'fa fa-toggle-left'                         => 'fab fa-toggle-left',
			'fa fa-toggle-off'                          => 'fab fa-toggle-off',
			'fa fa-toggle-on'                           => 'fab fa-toggle-on',
			'fa fa-toggle-right'                        => 'fab fa-toggle-right',
			'fa fa-toggle-up'                           => 'fab fa-toggle-up',
			'fa fa-trademark'                           => 'fab fa-trademark',
			'fa fa-train'                               => 'fab fa-train',
			'fa fa-transgender'                         => 'fab fa-transgender',
			'fa fa-transgender-alt'                     => 'fab fa-transgender-alt',
			'fa fa-trash'                               => 'fab fa-trash',
			'fa fa-trash-o'                             => 'fab fa-trash-o',
			'fa fa-tree'                                => 'fab fa-tree',
			'fa fa-trello'                              => 'fab fa-trello',
			'fa fa-tripadvisor'                         => 'fab fa-tripadvisor',
			'fa fa-trophy'                              => 'fab fa-trophy',
			'fa fa-truck'                               => 'fab fa-truck',
			'fa fa-try'                                 => 'fab fa-try',
			'fa fa-tty'                                 => 'fab fa-tty',
			'fa fa-tumblr'                              => 'fab fa-tumblr',
			'fa fa-tumblr-square'                       => 'fab fa-tumblr-square',
			'fa fa-turkish-lira'                        => 'fab fa-turkish-lira',
			'fa fa-tv'                                  => 'fab fa-tv',
			'fa fa-twitch'                              => 'fab fa-twitch',
			'fa fa-twitter'                             => 'fab fa-twitter',
			'fa fa-twitter-square'                      => 'fab fa-twitter-square',
			'fa fa-umbrella'                            => 'fab fa-umbrella',
			'fa fa-underline'                           => 'fab fa-underline',
			'fa fa-undo'                                => 'fab fa-undo',
			'fa fa-universal-access'                    => 'fab fa-universal-access',
			'fa fa-university'                          => 'fab fa-university',
			'fa fa-unlink'                              => 'fab fa-unlink',
			'fa fa-unlock'                              => 'fab fa-unlock',
			'fa fa-unlock-alt'                          => 'fab fa-unlock-alt',
			'fa fa-unsorted'                            => 'fab fa-unsorted',
			'fa fa-upload'                              => 'fab fa-upload',
			'fa fa-usb'                                 => 'fab fa-usb',
			'fa fa-usd'                                 => 'fab fa-usd',
			'fa fa-user'                                => 'fab fa-user',
			'fa fa-user-circle'                         => 'fab fa-user-circle',
			'fa fa-user-circle-o'                       => 'fab fa-user-circle-o',
			'fa fa-user-md'                             => 'fab fa-user-md',
			'fa fa-user-o'                              => 'fab fa-user-o',
			'fa fa-user-plus'                           => 'fab fa-user-plus',
			'fa fa-user-secret'                         => 'fab fa-user-secret',
			'fa fa-user-times'                          => 'fab fa-user-times',
			'fa fa-users'                               => 'fab fa-users',
			'fa fa-vcard'                               => 'fab fa-vcard',
			'fa fa-vcard-o'                             => 'fab fa-vcard-o',
			'fa fa-venus'                               => 'fab fa-venus',
			'fa fa-venus-double'                        => 'fab fa-venus-double',
			'fa fa-venus-mars'                          => 'fab fa-venus-mars',
			'fa fa-viacoin'                             => 'fab fa-viacoin',
			'fa fa-viadeo'                              => 'fab fa-viadeo',
			'fa fa-viadeo-square'                       => 'fab fa-viadeo-square',
			'fa fa-video-camera'                        => 'fab fa-video-camera',
			'fa fa-vimeo'                               => 'fab fa-vimeo',
			'fa fa-vimeo-square'                        => 'fab fa-vimeo-square',
			'fa fa-vine'                                => 'fab fa-vine',
			'fa fa-vk'                                  => 'fab fa-vk',
			'fa fa-volume-control-phone'                => 'fab fa-volume-control-phone',
			'fa fa-volume-down'                         => 'fab fa-volume-down',
			'fa fa-volume-off'                          => 'fab fa-volume-off',
			'fa fa-volume-up'                           => 'fab fa-volume-up',
			'fa fa-warning'                             => 'fab fa-warning',
			'fa fa-wechat'                              => 'fab fa-wechat',
			'fa fa-weibo'                               => 'fab fa-weibo',
			'fa fa-weixin'                              => 'fab fa-weixin',
			'fa fa-whatsapp'                            => 'fab fa-whatsapp',
			'fa fa-wheelchair'                          => 'fab fa-wheelchair',
			'fa fa-wheelchair-alt'                      => 'fab fa-wheelchair-alt',
			'fa fa-wifi'                                => 'fab fa-wifi',
			'fa fa-wikipedia-w'                         => 'fab fa-wikipedia-w',
			'fa fa-window-close'                        => 'fab fa-window-close',
			'fa fa-window-close-o'                      => 'fab fa-window-close-o',
			'fa fa-window-maximize'                     => 'fab fa-window-maximize',
			'fa fa-window-minimize'                     => 'fab fa-window-minimize',
			'fa fa-window-restore'                      => 'fab fa-window-restore',
			'fa fa-windows'                             => 'fab fa-windows',
			'fa fa-won'                                 => 'fab fa-won',
			'fa fa-wordpress'                           => 'fab fa-wordpress',
			'fa fa-wpbeginner'                          => 'fab fa-wpbeginner',
			'fa fa-wpexplorer'                          => 'fab fa-wpexplorer',
			'fa fa-wpforms'                             => 'fab fa-wpforms',
			'fa fa-wrench'                              => 'fab fa-wrench',
			'fa fa-xing'                                => 'fab fa-xing',
			'fa fa-xing-square'                         => 'fab fa-xing-square',
			'fa fa-y-combinator'                        => 'fab fa-y-combinator',
			'fa fa-y-combinator-square'                 => 'fab fa-y-combinator-square',
			'fa fa-yahoo'                               => 'fab fa-yahoo',
			'fa fa-yc'                                  => 'fab fa-yc',
			'fa fa-yc-square'                           => 'fab fa-yc-square',
			'fa fa-yelp'                                => 'fab fa-yelp',
			'fa fa-yen'                                 => 'fab fa-yen',
			'fa fa-yoast'                               => 'fab fa-yoast',
			'fa fa-youtube'                             => 'fab fa-youtube',
			'fa fa-youtube-play'                        => 'fab fa-youtube-play',
			'fa fa-youtube-square'                      => 'fab fa-youtube-square',
		];
	}
}